"use strict";
/**
 * MIT License
 *
 * Copyright (c) 2019 Douglas Nassif Roma Junior
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.requestAndroidPermission = void 0;
const react_native_1 = require("react-native");
const LocationError_1 = __importDefault(require("./LocationError"));
const { PERMISSIONS, RESULTS } = react_native_1.PermissionsAndroid;
async function requestAndroidPermission(enableHighAccuracy = false, rationale) {
    const permission = enableHighAccuracy
        ? PERMISSIONS.ACCESS_FINE_LOCATION
        : PERMISSIONS.ACCESS_COARSE_LOCATION;
    const alreadyGranted = await react_native_1.PermissionsAndroid.check(permission);
    if (alreadyGranted)
        return true;
    const granted = await react_native_1.PermissionsAndroid.request(permission, rationale);
    if (granted !== RESULTS.GRANTED) {
        throw new LocationError_1.default('UNAUTHORIZED', 'Authorization denied');
    }
    return true;
}
exports.requestAndroidPermission = requestAndroidPermission;
//# sourceMappingURL=utils.js.map